@@ -21,6 +21,7 @@ that works:
     fb.setupHorizontalHeader()
     fb.setupNameTable(...)
     fb.setupOS2()
+    fb.addOpenTypeFeatures(...)
     fb.setupPost()
     fb.save(...)
 
@@ -100,9 +101,10 @@ charString = pen.getCharString()
 charStrings = {".notdef": charString, "A": charString, "a": charString, ".null": charString}
 fb.setupCFF(nameStrings['psName'], {"FullName": nameStrings['psName']}, charStrings, {})
 
+lsb = {gn: cs.calcBounds(None)[0] for gn, cs in charStrings.items()}
 metrics = {}
 for gn, advanceWidth in advanceWidths.items():
-    metrics[gn] = (advanceWidth, 100)  # XXX lsb from glyph
+    metrics[gn] = (advanceWidth, lsb[gn])
 fb.setupHorizontalMetrics(metrics)
 
 fb.setupHorizontalHeader(ascent=824, descent=200)
@@ -298,7 +300,7 @@ _OS2Defaults = dict(
     sCapHeight = 0,
     usDefaultChar = 0,  # .notdef
     usBreakChar = 32,   # space
-    usMaxContext = 2,   # just kerning
+    usMaxContext = 0,
     usLowerOpticalPointSize = 0,
     usUpperOpticalPointSize = 0,
 )
@@ -364,9 +366,18 @@ class FontBuilder(object):
         """Set the glyph order for the font."""
         self.font.setGlyphOrder(glyphOrder)
 
-    def setupCharacterMap(self, cmapping, allowFallback=False):
+    def setupCharacterMap(self, cmapping, uvs=None, allowFallback=False):
         """Build the `cmap` table for the font. The `cmapping` argument should
         be a dict mapping unicode code points as integers to glyph names.
+
+        The `uvs` argument, when passed, must be a list of tuples, describing
+        Unicode Variation Sequences. These tuples have three elements:
+            (unicodeValue, variationSelector, glyphName)
+        `unicodeValue` and `variationSelector` are integer code points.
+        `glyphName` may be None, to indicate this is the default variation.
+        Text processors will then use the cmap to find the glyph name.
+        Each Unicode Variation Sequence should be an officially supported
+        sequence, but this is not policed.
         """
         subTables = []
         highestUnicode = max(cmapping)
@@ -390,18 +401,34 @@ class FontBuilder(object):
         subTable_0_3 = buildCmapSubTable(cmapping_3_1, format, 0, 3)
         subTables.append(subTable_0_3)
 
+        if uvs is not None:
+            uvsDict = {}
+            for unicodeValue, variationSelector, glyphName in uvs:
+                if cmapping.get(unicodeValue) == glyphName:
+                    # this is a default variation
+                    glyphName = None
+                if variationSelector not in uvsDict:
+                    uvsDict[variationSelector] = []
+                uvsDict[variationSelector].append((unicodeValue, glyphName))
+            uvsSubTable = buildCmapSubTable({}, 14, 0, 5)
+            uvsSubTable.uvsDict = uvsDict
+            subTables.append(uvsSubTable)
+
         self.font["cmap"] = newTable("cmap")
         self.font["cmap"].tableVersion = 0
         self.font["cmap"].tables = subTables
 
-    def setupNameTable(self, nameStrings):
+    def setupNameTable(self, nameStrings, windows=True, mac=True):
         """Create the `name` table for the font. The `nameStrings` argument must
         be a dict, mapping nameIDs or descriptive names for the nameIDs to name
         record values. A value is either a string, or a dict, mapping language codes
         to strings, to allow localized name table entries.
 
+        By default, both Windows (platformID=3) and Macintosh (platformID=1) name
+        records are added, unless any of `windows` or `mac` arguments is False.
+
         The following descriptive names are available for nameIDs:
-        
+
             copyright (nameID 0)
             familyName (nameID 1)
             styleName (nameID 2)
@@ -438,7 +465,9 @@ class FontBuilder(object):
                 nameID = _nameIDs[nameName]
             if isinstance(nameValue, basestring):
                 nameValue = dict(en=nameValue)
-            nameTable.addMultilingualName(nameValue, ttFont=self.font, nameID=nameID)
+            nameTable.addMultilingualName(
+                nameValue, ttFont=self.font, nameID=nameID, windows=windows, mac=mac
+            )
 
     def setupOS2(self, **values):
         """Create a new `OS/2` table and initialize it with default values,
@@ -663,8 +692,9 @@ class FontBuilder(object):
         """Create a new `post` table and initialize it with default values,
         which can be overridden by keyword arguments.
         """
+        isCFF2 = 'CFF2' in self.font
         postTable = self._initTableWithValues("post", _postDefaults, values)
-        if self.isTTF and keepGlyphNames:
+        if (self.isTTF or isCFF2) and keepGlyphNames:
             postTable.formatType = 2.0
             postTable.extraNames = []
             postTable.mapping = {}
@@ -682,25 +712,14 @@ class FontBuilder(object):
         self._initTableWithValues("maxp", defaults, {})
 
     def setupDummyDSIG(self):
-        """This adds a dummy DSIG table to the font to make some MS applications
+        """This adds an empty DSIG table to the font to make some MS applications
         happy. This does not properly sign the font.
         """
-        from .ttLib.tables.D_S_I_G_ import SignatureRecord
-
-        sig = SignatureRecord()
-        sig.ulLength = 20
-        sig.cbSignature = 12
-        sig.usReserved2 = 0
-        sig.usReserved1 = 0
-        sig.pkcs7 = b'\xd3M4\xd3M5\xd3M4\xd3M4'
-        sig.ulFormat = 1
-        sig.ulOffset = 20
-
         values = dict(
             ulVersion = 1,
-            usFlag = 1,
-            usNumSigs = 1,
-            signatureRecords = [sig],
+            usFlag = 0,
+            usNumSigs = 0,
+            signatureRecords = [],
         )
         self._initTableWithValues("DSIG", {}, values)
 
